@@ -41,6 +41,7 @@
 #include <kprocess.h>
 #include <kstandarddirs.h>
 #include <kgenericfactory.h>
+#include <kapplication.h>
 //END includes
 
 K_EXPORT_COMPONENT_FACTORY( kateinsertcommandplugin, KGenericFactory<PluginKateInsertCommand>( "kateinsertcommand" ) )
@@ -108,12 +109,16 @@ void PluginKateInsertCommand::removeView(Kate::MainWindow *win)
 
 void PluginKateInsertCommand::slotInsertCommand()
 {
+  if (!kapp->authorize("shell_access")) {
+      KMessageBox::sorry(0,i18n("You are not allowed to execute arbitrary external applications. If you want to be able to do this, contact your system administrator."),i18n("Access Restrictions"));
+      return;
+  }
   if ( sh && sh->isRunning() ) {
-    KMessageBox::sorry (0, i18n("A process is currently being executed."), 
-                        i18n("Error!"));
+    KMessageBox::sorry (0, i18n("A process is currently being executed."),
+                        i18n("Error"));
     return;
   }
-  
+
   if (!application()->activeMainWindow() || !application()->activeMainWindow()->viewManager()->activeView())
     return;
 
@@ -137,7 +142,7 @@ void PluginKateInsertCommand::slotInsertCommand()
       break;
   }
   dialogSettings = config->readNumEntry("Dialog Settings", 0);
-  CmdPrompt *d = new CmdPrompt((QWidget*)kv, 0, cmdhist, dir, 
+  CmdPrompt *d = new CmdPrompt((QWidget*)kv, 0, cmdhist, dir,
                                docdir, dialogSettings);
   if ( d->exec() && ! d->command().isEmpty() ) {
     if ( ! sh ) {
@@ -196,14 +201,14 @@ void PluginKateInsertCommand::slotAbort()
 {
   if ( sh->isRunning() )
     if (! sh->kill() )
-      KMessageBox::sorry(0, i18n("Could not kill command :o(("), i18n("Oops!"));
+      KMessageBox::sorry(0, i18n("Could not kill command."), i18n("Kill Failed"));
 }
 
 void PluginKateInsertCommand::slotShowWaitDlg()
 {
     if ( sh->isRunning() ) {
-      wdlg = new WaitDlg( (QWidget*)kv, QString( i18n(
-        "Executing command:\n%1\n\nPress 'Cancel' to abort.").arg(cmd) ) );
+      wdlg = new WaitDlg( (QWidget*)kv, i18n(
+        "Executing command:\n%1\n\nPress 'Cancel' to abort.").arg(cmd)  );
       connect(wdlg, SIGNAL(cancelClicked()), this, SLOT(slotAbort()) );
     }
     if ( sh->isRunning() )    // we may have finished while creating the dialog.
@@ -214,7 +219,7 @@ void PluginKateInsertCommand::slotShowWaitDlg()
     }
 }
 
-void PluginKateInsertCommand::slotReceivedStdout( KProcess* /*p*/, char* text, 
+void PluginKateInsertCommand::slotReceivedStdout( KProcess* /*p*/, char* text,
                                                   int len )
 {
   QString t = QString::fromLocal8Bit ( text );
@@ -222,7 +227,7 @@ void PluginKateInsertCommand::slotReceivedStdout( KProcess* /*p*/, char* text,
   kv->insertText( t );
 }
 
-void PluginKateInsertCommand::slotReceivedStderr( KProcess* p, char* text, 
+void PluginKateInsertCommand::slotReceivedStderr( KProcess* p, char* text,
                                                   int len )
 {
   if ( bInsStdErr )
@@ -237,19 +242,19 @@ void PluginKateInsertCommand::slotProcessExited( KProcess* p )
     wdlg = 0;
   }
   if ( ! p->normalExit() )
-    KMessageBox::sorry(0, QString(i18n("Command exited with status %1")).
+    KMessageBox::sorry(0, i18n("Command exited with status %1").
                               arg( p->exitStatus()), i18n("Oops!"));
   kv->setFocus();
 }
 //END PluginKateInsertCommand
 
 //BEGIN PluginConfigPage
-Kate::PluginConfigPage* PluginKateInsertCommand::configPage (uint, 
+Kate::PluginConfigPage* PluginKateInsertCommand::configPage (uint,
                                   QWidget *w, const char */*name*/)
 {
   InsertCommandConfigPage* p = new InsertCommandConfigPage(this, w);
   initConfigPage( p );
-  connect( p, SIGNAL(configPageApplyRequest(InsertCommandConfigPage*)), 
+  connect( p, SIGNAL(configPageApplyRequest(InsertCommandConfigPage*)),
            this, SLOT(applyConfig(InsertCommandConfigPage*)) );
   return (Kate::PluginConfigPage*)p;
 }
@@ -316,12 +321,12 @@ CmdPrompt::CmdPrompt(QWidget* parent,
 
    QWhatsThis::add( cmb_cmd, i18n(
      "Enter the shell command, the output of which you want inserted into your "
-     "document. Feel free to use a pipe or two if you're in that mood;-)") );
+     "document. Feel free to use a pipe or two if you wish.") );
    QWhatsThis::add( wdreq, i18n(
      "Sets the working folder of the command. The command executed is 'cd <dir> "
      "&& <command>'") );
    QWhatsThis::add( cb_insStdErr, i18n(
-     "Check this if you want the error output from <command> inserted too.\n"
+     "Check this if you want the error output from <command> inserted as well.\n"
      "Some commands, such as locate, print everything to STDERR") );
    QWhatsThis::add( cb_printCmd, i18n(
      "If you check this, the command string will be printed followed by a "
@@ -361,7 +366,7 @@ WaitDlg::~WaitDlg()
 
 //BEGIN InsertCommandConfigPage
 // This is the config page for this plugin.
-InsertCommandConfigPage::InsertCommandConfigPage(QObject* /*parent*/, 
+InsertCommandConfigPage::InsertCommandConfigPage(QObject* /*parent*/,
                                                  QWidget *parentWidget)
   : Kate::PluginConfigPage( parentWidget )
 {
@@ -373,7 +378,7 @@ InsertCommandConfigPage::InsertCommandConfigPage(QObject* /*parent*/,
   hb1->setSpacing(KDialogBase::spacingHint());
   (void) new QLabel( i18n("Remember"), hb1 );
   sb_cmdhistlen = new QSpinBox( hb1 );
-  QLabel *l1 =  new QLabel( sb_cmdhistlen, i18n("co&mmands"), hb1);
+  QLabel *l1 =  new QLabel( sb_cmdhistlen, i18n("Co&mmands"), hb1);
   hb1->setStretchFactor(l1, 1);
   lo->addWidget( hb1 );
 
