@@ -57,7 +57,7 @@ using domtreeviewer::ManipulationCommand;
 
 DOMTreeWindow::DOMTreeWindow(PluginDomtreeviewer *plugin)
     : KMainWindow( 0, "DOMTreeWindow" ),
-      plugin(plugin), m_view(new DOMTreeView(this, "DOMTreeView", false))
+      m_plugin(plugin), m_view(new DOMTreeView(this, "DOMTreeView", false))
 {
     part_manager = 0;
 
@@ -92,8 +92,6 @@ DOMTreeWindow::DOMTreeWindow(PluginDomtreeviewer *plugin)
     connect(view(), SIGNAL(htmlPartChanged(KHTMLPart *)),
     		SLOT(slotHtmlPartChanged(KHTMLPart *)));
 
-    connect(this, SIGNAL(windowClosed()), SLOT(slotDestroyed()));
-
     ManipulationCommand::connect(SIGNAL(error(int, const QString &)),
     				this, SLOT(addMessage(int, const QString &)));
 
@@ -104,7 +102,7 @@ DOMTreeWindow::DOMTreeWindow(PluginDomtreeviewer *plugin)
 
 DOMTreeWindow::~DOMTreeWindow()
 {
-    kdDebug(90180) << k_funcinfo << endl;
+    kdDebug(90180) << k_funcinfo << this << endl;
     delete m_commandHistory;
     delete msgdlg;
     delete _config;
@@ -121,16 +119,16 @@ void DOMTreeWindow::executeAndAddCommand(ManipulationCommand *cmd)
 
 void DOMTreeWindow::setupActions()
 {
-    KStdAction::close(this, SLOT(slotClose()), actionCollection());
+    KStdAction::close(this, SLOT(close()), actionCollection());
 
     KStdAction::cut(this, SLOT(slotCut()), actionCollection())->setEnabled(false);
     KStdAction::copy(this, SLOT(slotCopy()), actionCollection())->setEnabled(false);
     KStdAction::paste(this, SLOT(slotPaste()), actionCollection())->setEnabled(false);
 
     m_commandHistory = new KCommandHistory(actionCollection());
-    
+
     KStdAction::find(this, SLOT(slotFind()), actionCollection());
-    
+
     KStdAction::redisplay(m_view, SLOT(refresh()), actionCollection());
 
     // toggle manipulation dialog
@@ -248,37 +246,20 @@ void DOMTreeWindow::dropEvent(QDropEvent *event)
     }
 }
 
-void DOMTreeWindow::closeEvent(QCloseEvent *event)
-{
-  // HACK: call slot directly as destroyed() isn't
-  // emitted in QObject for some reason
-  plugin->slotDestroyed();
-  event->accept();
-}
-
 void DOMTreeWindow::addMessage(int msg_id, const QString &msg)
 {
   QDateTime t(QDateTime::currentDateTime());
   QString fullmsg = t.toString();
   fullmsg += ":";
-    
+
   if (msg_id != 0)
     fullmsg += " (" + QString::number(msg_id) + ") ";
   fullmsg += msg;
-    
+
   if (msgdlg) msgdlg->addMessage(fullmsg);
   view()->setMessage(msg);
   kdWarning() << fullmsg << endl;
 }
-
-void DOMTreeWindow::slotClose()
-{
-  // HACK: call slot directly as destroyed() isn't
-  // emitted in QObject for some reason
-  plugin->slotDestroyed();
-  deleteLater();
-}
-
 void DOMTreeWindow::slotCut()
 {
   // TODO implement
@@ -345,18 +326,19 @@ void DOMTreeWindow::changeCaption(const QString& text)
 {
     // display the text on the caption
     setCaption(text);
-}    
+}
 
 void DOMTreeWindow::slotHtmlPartChanged(KHTMLPart *p)
 {
   kdDebug(90180) << k_funcinfo << p << endl;
-  
+
   if (p) {
     // set up manager connections
-    disconnect(part_manager);
-    
+    if ( part_manager )
+        disconnect(part_manager);
+
     part_manager = p->manager();
-    
+
     connect(part_manager, SIGNAL(activePartChanged(KParts::Part *)),
     	SLOT(slotActivePartChanged(KParts::Part *)));
     connect(part_manager, SIGNAL(partRemoved(KParts::Part *)),
