@@ -1,4 +1,4 @@
-// Copyright (c) 2003,2004 Charles Samuels <charles@kde.org>
+// Copyright (c) 2003-2005 Charles Samuels <charles@kde.org>
 // See the file COPYING for redistribution terms.
 
 #ifndef OBLIQUE_H
@@ -9,11 +9,20 @@
 #include "query.h"
 #include "kdatacollection.h"
 
+#include <kio/global.h>
+
 class View;
 class Tree;
 class Base;
 class Selector;
 class TreeItem;
+class DirectoryAdder;
+
+namespace KIO
+{
+	class ListJob;
+	class Job;
+}
 
 class Oblique : public Playlist, public Plugin
 {
@@ -22,6 +31,8 @@ Q_OBJECT
 	Base *mBase;
 	Selector *mSelector;
 	KDataCollection mSchemaCollection;
+	DirectoryAdder *mAdder;
+	
 
 public:
 	Oblique();
@@ -65,9 +76,11 @@ public:
 
 public slots:
 	void selected(TreeItem *cur);
+	void beginDirectoryAdd(const KURL &url);
 
 private slots:
 	void loopTypeChange(int i);
+	void adderDone();
 };
 
 /**
@@ -91,5 +104,39 @@ private slots:
 	void loadItemsDeferred();
 };
 
+/**
+ * Adds a directory to
+ * emits @ref done() when finished so you
+ * can delete it
+ **/
+class DirectoryAdder : public QObject
+{
+	Q_OBJECT
+	Oblique *mOblique;
+	KURL::List pendingAddDirectories;
+	KURL::List::Iterator lastAddedSubDirectory;
+	KIO::ListJob *listJob;
+	KURL currentJobURL;
+
+public:
+	DirectoryAdder(const KURL &dir, Oblique *oblique);
+	
+	Oblique *oblique() { return mOblique; }
+
+public slots:
+	void add(const KURL &dir);
+
+signals:
+	void done();
+
+private slots:
+	void slotResult(KIO::Job *job);
+	void slotEntries(KIO::Job *job, const KIO::UDSEntryList &entries);
+	void slotRedirection(KIO::Job *, const KURL & url);
+
+private:
+	
+	void addNextPending();
+};
 
 #endif
